@@ -6,8 +6,9 @@ from __future__ import division, unicode_literals, print_function, absolute_impo
 import doctest
 from distutils.version import StrictVersion
 import re
+import unittest
 
-from pint.compat import unittest, HAS_NUMPY, HAS_UNCERTAINTIES, NUMPY_VER, PYTHON3
+from pint.compat import HAS_NUMPY, HAS_PROPER_BABEL, HAS_UNCERTAINTIES, NUMPY_VER, PYTHON3
 
 
 def requires_numpy18():
@@ -30,6 +31,10 @@ def requires_not_numpy():
     return unittest.skipIf(HAS_NUMPY, 'Requires NumPy is not installed.')
 
 
+def requires_proper_babel():
+    return unittest.skipUnless(HAS_PROPER_BABEL, 'Requires Babel with units support')
+
+
 def requires_uncertainties():
     return unittest.skipUnless(HAS_UNCERTAINTIES, 'Requires Uncertainties')
 
